@@ -12,107 +12,147 @@ from polls.models import Choice, Poll, UserChoice
 from polls.forms import PollForm, PollVoteForm
 from polls.methods import get_poll_form, get_poll_vote_form
 
+
 class PollListView(ListView):
     template_name = 'polls/index.html'
 
     def get_queryset(self):
-        return Poll.objects.filter(user=self.request.user).order_by('-created')
-        
+        if self.request.user.is_authenticated():
+            return Poll.objects.filter(user=self.request.user)
+        else:
+            return []
+
+
 class ResultsView(DetailView):
     model = Poll
     template_name = 'polls/results.html'
-    
+
+
 class PollVoteView(FormView):
     form_class = PollVoteForm
     template_name = 'polls/vote.html'
     success_url = '/'
     pk = None
     form = None
-    
+
     def get(self, request, *args, **kwargs):
         self.pk = kwargs.get('pk')
         poll = Poll.objects.get(pk=self.pk)
-        
+
         self.form = get_poll_vote_form(poll)
-        
+
         return super(PollVoteView, self).get(request, *args, **kwargs)
-    
+
     def post(self, request, *args, **kwargs):
+        ANONYMOUS_VOTING = getattr(
+            settings,
+            'POLL_ANONYMOUS_VOTING_ENABLED',
+            False)
+
         self.pk = kwargs.get('pk')
         self.form = PollVoteForm(request.POST)
         user = request.user
         poll = Poll.objects.get(pk=self.pk)
-        
-        if user.is_authenticated():
-            if not poll.has_voted(user):
-                if len(request.POST.getlist('choice')) > 0:
-                    for choice in request.POST.getlist('choice'):
-                        choice = Choice.objects.get(pk=choice)
-                        UserChoice(poll=poll, choice=choice, user=self.request.user).save()
-                        choice.votes += 1
-                        choice.save()
-                    return HttpResponseRedirect(reverse('poll_results', kwargs={'pk': self.pk}))
-                else:
-                    messages.add_message(request, messages.WARNING, 'Select a choice.')
-                    return HttpResponseRedirect(request.path)
-            else:
-                messages.add_message(request, messages.WARNING, 'You have already voted in the poll.')
-                return HttpResponseRedirect(request.path)
+
+        if not user.is_authenticated() and not ANONYMOUS_VOTING:
+            return (
+                HttpResponseRedirect(
+                    '%s?%s' %
+                    (settings.LOGIN_URL, request.path))
+            )
+
+        if user.is_authenticated() and poll.has_voted(user):
+            messages.add_message(
+                request,
+                messages.WARNING,
+                'You have already voted in the poll.')
+            return HttpResponseRedirect(request.path)
+
+        if len(request.POST.getlist('choice')) > 0:
+            for choice in request.POST.getlist('choice'):
+                choice = Choice.objects.get(pk=choice)
+
+                if user.is_authenticated():
+                    UserChoice(
+                        poll=poll,
+                        choice=choice,
+                        user=self.request.user).save()
+
+                choice.votes += 1
+                choice.save()
+            return (
+                HttpResponseRedirect(
+                    reverse('poll_results',
+                            kwargs={'pk': self.pk}))
+            )
         else:
-            return HttpResponseRedirect('%s?%s' % (settings.LOGIN_URL, request.path))
+            messages.add_message(request, messages.WARNING, 'Select a choice.')
+            return HttpResponseRedirect(request.path)
 
     def get_context_data(self, *args, **kwargs):
         context = super(PollVoteView, self).get_context_data(*args, **kwargs)
 
         pk = self.pk
-        
+
         instance = Poll.objects.get(pk=pk)
-        
+
         context['pk'] = pk
         context['form'] = self.form
         context['instance'] = instance
-        
+
         return context
-        
+
+
 class PollView(FormView):
     form_class = PollForm
     template_name = 'polls/poll/poll.html'
-    
+
     def get(self, request, *args, **kwargs):
         pk = kwargs.get('pk')
-        
+
         if pk:
             instance = Poll.objects.get(pk=pk)
             if request.user != instance.user:
-                return HttpResponseRedirect('%s?%s' % (settings.LOGIN_URL, request.path))
+                return (
+                    HttpResponseRedirect(
+                        '%s?%s' %
+                        (settings.LOGIN_URL, request.path))
+                )
         else:
             instance = None
-        
+
         form, formset = get_poll_form(instance, request)
-        
+
         context = dict(form=form, formset=formset)
-        
+
         return render(request, self.template_name, context)
-    
+
     def post(self, request, *args, **kwargs):
         pk = kwargs.get('pk')
-        
+
         if pk:
             instance = Poll.objects.get(pk=pk)
             if request.user != instance.user:
-                return HttpResponseRedirect('%s?%s' % (settings.LOGIN_URL, request.path))
+                return (
+                    HttpResponseRedirect(
+                        '%s?%s' %
+                        (settings.LOGIN_URL, request.path))
+                )
         else:
             instance = None
-        
+
         data = request.POST
-        
+
         form, formset = get_poll_form(instance, request)
-        
+
         if form.is_valid() and formset.is_valid():
             form.save()
             formset.save()
-            return HttpResponseRedirect(reverse('poll_vote', kwargs={'pk': form.instance.pk}))  
+            return (
+                HttpResponseRedirect(
+                    reverse('poll_vote', kwargs={'pk': form.instance.pk}))
+            )
         else:
             context = dict(form=form, formset=formset)
-            
-        return render(request, self.template_name, context)
\ No newline at end of file
+
+        return render(request, self.template_name, context)
